==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/CapabilitiesUpdateObject.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.LifecycleDeactivateSettingObject;
import com.okta.sdk.resource.model.PasswordSettingObject;
import com.okta.sdk.resource.model.ProfileSettingObject;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Determines whether updates to a user&#39;s profile are pushed to the app
 */
@ApiModel(description = "Determines whether updates to a user's profile are pushed to the app")
@JsonPropertyOrder({ CapabilitiesUpdateObject.JSON_PROPERTY_LIFECYCLE_DEACTIVATE,
        CapabilitiesUpdateObject.JSON_PROPERTY_PASSWORD, CapabilitiesUpdateObject.JSON_PROPERTY_PROFILE })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class CapabilitiesUpdateObject implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_LIFECYCLE_DEACTIVATE = "lifecycleDeactivate";
    private LifecycleDeactivateSettingObject lifecycleDeactivate;

    public static final String JSON_PROPERTY_PASSWORD = "password";
    private PasswordSettingObject password;

    public static final String JSON_PROPERTY_PROFILE = "profile";
    private ProfileSettingObject profile;

    public CapabilitiesUpdateObject() {
    }

    public CapabilitiesUpdateObject lifecycleDeactivate(LifecycleDeactivateSettingObject lifecycleDeactivate) {

        this.lifecycleDeactivate = lifecycleDeactivate;
        return this;
    }

    /**
     * Get lifecycleDeactivate
     *
     * @return lifecycleDeactivate
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_LIFECYCLE_DEACTIVATE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public LifecycleDeactivateSettingObject getLifecycleDeactivate() {
        return lifecycleDeactivate;
    }

    @JsonProperty(JSON_PROPERTY_LIFECYCLE_DEACTIVATE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setLifecycleDeactivate(LifecycleDeactivateSettingObject lifecycleDeactivate) {
        this.lifecycleDeactivate = lifecycleDeactivate;
    }

    public CapabilitiesUpdateObject password(PasswordSettingObject password) {

        this.password = password;
        return this;
    }

    /**
     * Get password
     *
     * @return password
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_PASSWORD)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PasswordSettingObject getPassword() {
        return password;
    }

    @JsonProperty(JSON_PROPERTY_PASSWORD)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setPassword(PasswordSettingObject password) {
        this.password = password;
    }

    public CapabilitiesUpdateObject profile(ProfileSettingObject profile) {

        this.profile = profile;
        return this;
    }

    /**
     * Get profile
     *
     * @return profile
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_PROFILE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public ProfileSettingObject getProfile() {
        return profile;
    }

    @JsonProperty(JSON_PROPERTY_PROFILE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setProfile(ProfileSettingObject profile) {
        this.profile = profile;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        CapabilitiesUpdateObject capabilitiesUpdateObject = (CapabilitiesUpdateObject) o;
        return Objects.equals(this.lifecycleDeactivate, capabilitiesUpdateObject.lifecycleDeactivate)
                && Objects.equals(this.password, capabilitiesUpdateObject.password)
                && Objects.equals(this.profile, capabilitiesUpdateObject.profile);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(lifecycleDeactivate, password, profile);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class CapabilitiesUpdateObject {\n");
        sb.append("    lifecycleDeactivate: ").append(toIndentedString(lifecycleDeactivate)).append("\n");
        sb.append("    password: ").append(toIndentedString(password)).append("\n");
        sb.append("    profile: ").append(toIndentedString(profile)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-21.0.0-sources.jar: com/okta/sdk/resource/model/CapabilitiesUpdateObject.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.LifecycleDeactivateSettingObject;
import com.okta.sdk.resource.model.PasswordSettingObject;
import com.okta.sdk.resource.model.ProfileSettingObject;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Determines whether updates to a user&#39;s profile are pushed to the app
 */
@ApiModel(description = "Determines whether updates to a user's profile are pushed to the app")
@JsonPropertyOrder({ CapabilitiesUpdateObject.JSON_PROPERTY_LIFECYCLE_DEACTIVATE,
        CapabilitiesUpdateObject.JSON_PROPERTY_PASSWORD, CapabilitiesUpdateObject.JSON_PROPERTY_PROFILE })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class CapabilitiesUpdateObject implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_LIFECYCLE_DEACTIVATE = "lifecycleDeactivate";
    private LifecycleDeactivateSettingObject lifecycleDeactivate;

    public static final String JSON_PROPERTY_PASSWORD = "password";
    private PasswordSettingObject password;

    public static final String JSON_PROPERTY_PROFILE = "profile";
    private ProfileSettingObject profile;

    public CapabilitiesUpdateObject() {
    }

    public CapabilitiesUpdateObject lifecycleDeactivate(LifecycleDeactivateSettingObject lifecycleDeactivate) {

        this.lifecycleDeactivate = lifecycleDeactivate;
        return this;
    }

    /**
     * Get lifecycleDeactivate
     *
     * @return lifecycleDeactivate
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_LIFECYCLE_DEACTIVATE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public LifecycleDeactivateSettingObject getLifecycleDeactivate() {
        return lifecycleDeactivate;
    }

    @JsonProperty(JSON_PROPERTY_LIFECYCLE_DEACTIVATE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setLifecycleDeactivate(LifecycleDeactivateSettingObject lifecycleDeactivate) {
        this.lifecycleDeactivate = lifecycleDeactivate;
    }

    public CapabilitiesUpdateObject password(PasswordSettingObject password) {

        this.password = password;
        return this;
    }

    /**
     * Get password
     *
     * @return password
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_PASSWORD)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PasswordSettingObject getPassword() {
        return password;
    }

    @JsonProperty(JSON_PROPERTY_PASSWORD)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setPassword(PasswordSettingObject password) {
        this.password = password;
    }

    public CapabilitiesUpdateObject profile(ProfileSettingObject profile) {

        this.profile = profile;
        return this;
    }

    /**
     * Get profile
     *
     * @return profile
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_PROFILE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public ProfileSettingObject getProfile() {
        return profile;
    }

    @JsonProperty(JSON_PROPERTY_PROFILE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setProfile(ProfileSettingObject profile) {
        this.profile = profile;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        CapabilitiesUpdateObject capabilitiesUpdateObject = (CapabilitiesUpdateObject) o;
        return Objects.equals(this.lifecycleDeactivate, capabilitiesUpdateObject.lifecycleDeactivate)
                && Objects.equals(this.password, capabilitiesUpdateObject.password)
                && Objects.equals(this.profile, capabilitiesUpdateObject.profile);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(lifecycleDeactivate, password, profile);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class CapabilitiesUpdateObject {\n");
        sb.append("    lifecycleDeactivate: ").append(toIndentedString(lifecycleDeactivate)).append("\n");
        sb.append("    password: ").append(toIndentedString(password)).append("\n");
        sb.append("    profile: ").append(toIndentedString(profile)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
